@@ -1,6 +1,6 @@
 /** @file
 
-  A brief file description
+  A thin wrapper for pthread rwlocks.
 
   @section license License
 
@@ -37,7 +37,22 @@ typedef pthread_rwlock_t ink_rwlock;
 void ink_rwlock_init(ink_rwlock *rw);
 void ink_rwlock_destroy(ink_rwlock *rw);
 
-static inline void
+// Instead of calling ink_rwlock_init(), an ink_rwlock instance can be initialized with one of thsee values.
+//
+ink_rwlock const INK_RWLOCK_INIT = PTHREAD_RWLOCK_INITIALIZER;
+#if defined(linux)
+ink_rwlock const INK_RWLOCK_INIT_NO_WRITER_STARVATION = PTHREAD_RWLOCK_WRITER_NONRECURSIVE_INITIALIZER_NP;
+#else
+// Testing indicates that for MacOS/Darwin and FreeBSD, pthread rwlocks always prevent writer starvation.
+//
+ink_rwlock const INK_RWLOCK_INIT_NO_WRITER_STARVATION = INK_RWLOCK_INIT;
+
+#if !(defined(darwin) || defined(freebsd))
+#warning "Use of ink_rwlock may result in writer starvation"
+#endif
+#endif
+
+inline void
 ink_rwlock_rdlock(ink_rwlock *rw)
 {
   int error = pthread_rwlock_rdlock(rw);
@@ -46,7 +61,20 @@ ink_rwlock_rdlock(ink_rwlock *rw)
   }
 }
 
-static inline void
+inline bool
+ink_rwlock_tryrdlock(ink_rwlock *rw)
+{
+  int error = pthread_rwlock_tryrdlock(rw);
+  if (EBUSY == error) {
+    return false;
+  }
+  if (unlikely(error != 0)) {
+    ink_abort("pthread_rwlock_tryrdlock(%p) failed: %s (%d)", rw, strerror(error), error);
+  }
+  return true;
+}
+
+inline void
 ink_rwlock_wrlock(ink_rwlock *rw)
 {
   int error = pthread_rwlock_wrlock(rw);
@@ -55,7 +83,20 @@ ink_rwlock_wrlock(ink_rwlock *rw)
   }
 }
 
-static inline void
+inline bool
+ink_rwlock_trywrlock(ink_rwlock *rw)
+{
+  int error = pthread_rwlock_trywrlock(rw);
+  if (EBUSY == error) {
+    return false;
+  }
+  if (unlikely(error != 0)) {
+    ink_abort("pthread_rwlock_trywrlock(%p) failed: %s (%d)", rw, strerror(error), error);
+  }
+  return true;
+}
+
+inline void
 ink_rwlock_unlock(ink_rwlock *rw)
 {
   int error = pthread_rwlock_unlock(rw);
