@@ -307,7 +307,7 @@ CacheVC::openReadFromWriter(int event, Event *e)
     // before the open_write, but the reader could not get the volume
     // lock. If we don't reset the clock here, we won't choose any writer
     // and hence fail the read request.
-    start_time                = Thread::get_hrtime();
+    start_time                = ink_get_hrtime();
     f.read_from_writer_called = 1;
   }
   cancel_trigger();
@@ -614,19 +614,20 @@ CacheVC::openReadReadDone(int event, Event *e)
       }
     }
     // fall through for truncated documents
+  Lerror : {
+    // Keep the lock on vol->mutex, for dir_delete.
+    char tmpstring[CRYPTO_HEX_SIZE];
+    if (request.valid()) {
+      int url_length;
+      const char *url_text = request.url_get()->string_get_ref(&url_length);
+      Warning("Document %s truncated, url[%.*s] .. clearing", earliest_key.toHexStr(tmpstring), url_length, url_text);
+    } else {
+      Warning("Document %s truncated .. clearing", earliest_key.toHexStr(tmpstring));
+    }
+    dir_delete(&earliest_key, vol, &earliest_dir);
   }
-Lerror : {
-  char tmpstring[CRYPTO_HEX_SIZE];
-  if (request.valid()) {
-    int url_length;
-    const char *url_text = request.url_get()->string_get_ref(&url_length);
-    Warning("Document %s truncated, url[%.*s] .. clearing", earliest_key.toHexStr(tmpstring), url_length, url_text);
-  } else {
-    Warning("Document %s truncated .. clearing", earliest_key.toHexStr(tmpstring));
   }
-  dir_delete(&earliest_key, vol, &earliest_dir);
   return calluser(VC_EVENT_ERROR);
-}
 Ldone:
   return calluser(VC_EVENT_EOS);
 Lcallreturn:
@@ -749,6 +750,8 @@ CacheVC::openReadMain(int /* event ATS_UNUSED */, Event * /* e ATS_UNUSED */)
 
       doc->magic = DOC_CORRUPT;
 
+      CACHE_INCREMENT_DYN_STAT(cache_read_seek_fail_stat);
+
       CACHE_TRY_LOCK(lock, vol->mutex, mutex->thread_holding);
       if (!lock.is_locked()) {
         SET_HANDLER(&CacheVC::openReadDirDelete);
@@ -1173,6 +1176,20 @@ CacheVC::openReadStartHead(int event, Event *e)
       } else {
         f.single_fragment = false;
       }
+
+      // Now that we have selected an alternate, validate that the content length and object size match
+      MIMEField *field = alternate.response_get()->field_find(MIME_FIELD_CONTENT_LENGTH, MIME_LEN_CONTENT_LENGTH);
+      if (field) {
+        uint64_t cl = static_cast<uint64_t>(field->value_get_int64());
+        if (cl != doc_len) {
+          Warning("OpenReadHead failed for cachekey %X : alternate content length doesn't match doc_len %" PRId64 " != %" PRId64,
+                  key.slice32(0), cl, doc_len);
+          CACHE_INCREMENT_DYN_STAT(cache_read_invalid_stat);
+          err = ECACHE_BAD_META_DATA;
+          goto Ldone;
+        }
+      }
+
     } else {
       next_CacheKey(&key, &doc->key);
       f.single_fragment = doc->single_fragment();
