@@ -30,19 +30,14 @@
 
 #pragma once
 
-/*
-#include "P_DNS.h"
-#include "I_SplitDNS.h"
-#include "I_Lock.h"
-#include "ControlBase.h"
-#include "ControlMatcher.h"
-*/
 #include "ProxyConfig.h"
 
+#include "tscore/HostLookup.h"
+
 /* ---------------------------
    forward declarations ...
    --------------------------- */
-void ink_split_dns_init(ModuleVersion version);
+void ink_split_dns_init(ts::ModuleVersion version);
 
 struct RequestData;
 
@@ -70,18 +65,11 @@ struct SplitDNSResult {
   /* ------------
      public
      ------------ */
-  DNSResultType r;
+  DNSResultType r = DNS_SRVR_UNDEFINED;
 
-  DNSServer *get_dns_record();
-  int get_dns_srvr_count();
+  int m_line_number = 0;
 
-  /* ------------
-     private
-     ------------ */
-  int m_line_number;
-
-  SplitDNSRecord *m_rec;
-  bool m_wrap_around;
+  SplitDNSRecord *m_rec = nullptr;
 };
 
 /* --------------------------------------------------------------
@@ -94,17 +82,17 @@ struct SplitDNS : public ConfigInfo {
   void *getDNSRecord(const char *hostname);
   void findServer(RequestData *rdata, SplitDNSResult *result);
 
-  DNS_table *m_DNSSrvrTable;
+  DNS_table *m_DNSSrvrTable = nullptr;
 
-  int32_t m_SplitDNSlEnable;
+  int32_t m_SplitDNSlEnable = 0;
 
   /* ----------------------------
      required by the alleged fast
      path
      ---------------------------- */
-  bool m_bEnableFastPath;
-  void *m_pxLeafArray;
-  int m_numEle;
+  bool m_bEnableFastPath               = false;
+  HostLookup::LeafArray *m_pxLeafArray = nullptr;
+  int m_numEle                         = 0;
 };
 
 /* --------------------------------------------------------------
@@ -130,21 +118,21 @@ class DNSRequestData : public RequestData
 public:
   DNSRequestData();
 
-  char *get_string();
+  char *get_string() override;
 
-  const char *get_host();
+  const char *get_host() override;
 
-  sockaddr const *get_ip();        // unused required virtual method.
-  sockaddr const *get_client_ip(); // unused required virtual method.
+  sockaddr const *get_ip() override;        // unused required virtual method.
+  sockaddr const *get_client_ip() override; // unused required virtual method.
 
-  const char *m_pHost;
+  const char *m_pHost = nullptr;
 };
 
 /* --------------------------------------------------------------
    DNSRequestData::get_string()
    -------------------------------------------------------------- */
 TS_INLINE
-DNSRequestData::DNSRequestData() : m_pHost(nullptr) {}
+DNSRequestData::DNSRequestData() {}
 
 /* --------------------------------------------------------------
    DNSRequestData::get_string()
@@ -200,28 +188,20 @@ public:
   const char *ProcessDefDomain(char *val);
 
   void UpdateMatch(SplitDNSResult *result, RequestData *rdata);
-  void Print();
+  void Print() const;
 
   DNSServer m_servers;
-  int m_dnsSrvr_cnt;
-  int m_domain_srch_list;
+  int m_dnsSrvr_cnt      = 0;
+  int m_domain_srch_list = 0;
 };
 
 /* --------------------------------------------------------------
    SplitDNSRecord::SplitDNSRecord()
    -------------------------------------------------------------- */
 TS_INLINE
-SplitDNSRecord::SplitDNSRecord() : m_dnsSrvr_cnt(0), m_domain_srch_list(0) {}
+SplitDNSRecord::SplitDNSRecord() {}
 
 /* --------------------------------------------------------------
    SplitDNSRecord::~SplitDNSRecord()
    -------------------------------------------------------------- */
 TS_INLINE SplitDNSRecord::~SplitDNSRecord() {}
-
-/* ------------------
-   Helper Functions
-   ------------------ */
-
-SplitDNSRecord *createDefaultServer();
-void reloadDefaultParent(char *val);
-void reloadParentFile();
