@@ -126,9 +126,9 @@ class EThread;
 typedef EThread *EThreadPtr;
 
 #if DEBUG
-inkcoreapi extern void lock_waiting(const SourceLocation &, const char *handler);
-inkcoreapi extern void lock_holding(const SourceLocation &, const char *handler);
-inkcoreapi extern void lock_taken(const SourceLocation &, const char *handler);
+extern void lock_waiting(const SourceLocation &, const char *handler);
+extern void lock_holding(const SourceLocation &, const char *handler);
+extern void lock_taken(const SourceLocation &, const char *handler);
 #endif
 
 /**
@@ -249,7 +249,7 @@ public:
 };
 
 // The ClassAllocator for ProxyMutexes
-extern inkcoreapi ClassAllocator<ProxyMutex> mutexAllocator;
+extern ClassAllocator<ProxyMutex> mutexAllocator;
 
 inline bool
 Mutex_trylock(
@@ -277,7 +277,7 @@ Mutex_trylock(
 #ifdef DEBUG
     m->srcloc    = location;
     m->handler   = ahandler;
-    m->hold_time = Thread::get_hrtime();
+    m->hold_time = ink_get_hrtime();
 #ifdef MAX_LOCK_TAKEN
     m->taken++;
 #endif // MAX_LOCK_TAKEN
@@ -324,7 +324,7 @@ Mutex_lock(
 #ifdef DEBUG
     m->srcloc    = location;
     m->handler   = ahandler;
-    m->hold_time = Thread::get_hrtime();
+    m->hold_time = ink_get_hrtime();
 #ifdef MAX_LOCK_TAKEN
     m->taken++;
 #endif // MAX_LOCK_TAKEN
@@ -363,7 +363,7 @@ Mutex_unlock(ProxyMutex *m, EThread *t)
     m->nthread_holding--;
     if (!m->nthread_holding) {
 #ifdef DEBUG
-      if (Thread::get_hrtime() - m->hold_time > MAX_LOCK_TIME)
+      if (ink_get_hrtime() - m->hold_time > MAX_LOCK_TIME)
         lock_holding(m->srcloc, m->handler);
 #ifdef MAX_LOCK_TAKEN
       if (m->taken > MAX_LOCK_TAKEN)
