@@ -29,7 +29,6 @@
 #include "P_EventSystem.h"
 
 #include "tscore/TextBuffer.h"
-#include "tscore/TestBox.h"
 
 SocketManager socketManager;
 
@@ -66,10 +65,8 @@ accept4(int sockfd, struct sockaddr *addr, socklen_t *addrlen, int flags)
 int
 SocketManager::accept4(int s, struct sockaddr *addr, socklen_t *addrlen, int flags)
 {
-  int fd;
-
   do {
-    fd = ::accept4(s, addr, addrlen, flags);
+    int fd = ::accept4(s, addr, addrlen, flags);
     if (likely(fd >= 0)) {
       return fd;
     }
@@ -129,18 +126,3 @@ SocketManager::fastopen_supported()
 
   return value & TFO_CLIENT_ENABLE;
 }
-
-REGRESSION_TEST(socket_fastopen)(RegressionTest *test, int level, int *pstatus)
-{
-  TestBox box(test, pstatus);
-
-  box = REGRESSION_TEST_PASSED;
-
-  if (SocketManager::fastopen_supported()) {
-    box.check(MSG_FASTOPEN != 0, "TCP Fast Open is supported, MSG_FASTOPEN must not be 0");
-  }
-
-  if (::access("/proc/sys/net/ipv4/tcp_fastopen", F_OK) == 0) {
-    box.check(MSG_FASTOPEN != 0, "TCP Fast Open is available, MSG_FASTOPEN must not be 0");
-  }
-}
