@@ -28,9 +28,6 @@
 
 #include "I_EventSystem.h"
 #include "RecordsConfig.h"
-#if defined(darwin)
-#include "P_IOBuffer.h"
-#endif
 
 #include "diags.i"
 
