@@ -26,7 +26,5 @@
  *
  */
 
-#if !(defined(darwin) && defined(__aarch64__))
 #define TS_INLINE
 #include "P_HostDB.h"
-#endif
