@@ -28,17 +28,21 @@
 
 **************************************************************************/
 #include "tscore/ink_platform.h"
+#include "tscore/ink_defs.h"
 
 #include "P_Net.h"
 
+#ifdef SO_ACCEPTFILTER
+#include <sys/param.h>
+#include <sys/linker.h>
+#endif
+
 // set in the OS
 // #define RECV_BUF_SIZE            (1024*64)
 // #define SEND_BUF_SIZE            (1024*64)
 #define FIRST_RANDOM_PORT 16000
 #define LAST_RANDOM_PORT 32000
 
-#define ROUNDUP(x, y) ((((x) + ((y)-1)) / (y)) * (y))
-
 int
 get_listen_backlog()
 {
@@ -57,7 +61,7 @@ NetVCOptions::toString(addr_bind_style s)
   return ANY_ADDR == s ? "any" : INTF_ADDR == s ? "interface" : "foreign";
 }
 
-Connection::Connection() : fd(NO_FD), is_bound(false), is_connected(false), sock_type(0)
+Connection::Connection() : fd(NO_FD)
 {
   memset(&addr, 0, sizeof(addr));
 }
@@ -136,11 +140,13 @@ add_http_filter(int fd ATS_UNUSED)
 int
 Server::setup_fd_for_listen(bool non_blocking, const NetProcessor::AcceptOptions &opt)
 {
-  int res = 0;
+  int res               = 0;
+  int listen_per_thread = 0;
 
   ink_assert(fd != NO_FD);
 
-  if (http_accept_filter) {
+  if (opt.etype == ET_NET && opt.defer_accept > 0) {
+    http_accept_filter = true;
     add_http_filter(fd);
   }
 
@@ -199,7 +205,7 @@ Server::setup_fd_for_listen(bool non_blocking, const NetProcessor::AcceptOptions
     l.l_onoff  = 0;
     l.l_linger = 0;
     if ((opt.sockopt_flags & NetVCOptions::SOCK_OPT_LINGER_ON) &&
-        safe_setsockopt(fd, SOL_SOCKET, SO_LINGER, (char *)&l, sizeof(l)) < 0) {
+        safe_setsockopt(fd, SOL_SOCKET, SO_LINGER, reinterpret_cast<char *>(&l), sizeof(l)) < 0) {
       goto Lerror;
     }
   }
@@ -211,6 +217,17 @@ Server::setup_fd_for_listen(bool non_blocking, const NetProcessor::AcceptOptions
   if (safe_setsockopt(fd, SOL_SOCKET, SO_REUSEADDR, SOCKOPT_ON, sizeof(int)) < 0) {
     goto Lerror;
   }
+  REC_ReadConfigInteger(listen_per_thread, "proxy.config.exec_thread.listen");
+  if (listen_per_thread == 1) {
+    if (safe_setsockopt(fd, SOL_SOCKET, SO_REUSEPORT, SOCKOPT_ON, sizeof(int)) < 0) {
+      goto Lerror;
+    }
+#ifdef SO_REUSEPORT_LB
+    if (safe_setsockopt(fd, SOL_SOCKET, SO_REUSEPORT_LB, SOCKOPT_ON, sizeof(int)) < 0) {
+      goto Lerror;
+    }
+#endif
+  }
 
   if ((opt.sockopt_flags & NetVCOptions::SOCK_OPT_NO_DELAY) &&
       safe_setsockopt(fd, IPPROTO_TCP, TCP_NODELAY, SOCKOPT_ON, sizeof(int)) < 0) {
@@ -247,12 +264,33 @@ Server::setup_fd_for_listen(bool non_blocking, const NetProcessor::AcceptOptions
 
 #if defined(TCP_MAXSEG)
   if (NetProcessor::accept_mss > 0) {
-    if (safe_setsockopt(fd, IPPROTO_TCP, TCP_MAXSEG, (char *)&NetProcessor::accept_mss, sizeof(int)) < 0) {
+    if (safe_setsockopt(fd, IPPROTO_TCP, TCP_MAXSEG, reinterpret_cast<char *>(&NetProcessor::accept_mss), sizeof(int)) < 0) {
       goto Lerror;
     }
   }
 #endif
 
+  if (opt.f_mptcp) {
+#if MPTCP_ENABLED
+    if (safe_setsockopt(fd, IPPROTO_TCP, MPTCP_ENABLED, SOCKOPT_ON, sizeof(int)) < 0) {
+      Error("[Server::listen] Unable to enable MPTCP socket-option [%d] %s\n", errno, strerror(errno));
+      goto Lerror;
+    }
+#else
+    Error("[Server::listen] Multipath TCP requested but not configured on this host\n");
+#endif
+  }
+
+#ifdef TCP_DEFER_ACCEPT
+  // set tcp defer accept timeout if it is configured, this will not trigger an accept until there is
+  // data on the socket ready to be read
+  if (opt.defer_accept > 0 && setsockopt(fd, IPPROTO_TCP, TCP_DEFER_ACCEPT, &opt.defer_accept, sizeof(int)) < 0) {
+    // FIXME: should we go to the error
+    // goto error;
+    Error("[Server::listen] Defer accept is configured but set failed: %d", errno);
+  }
+#endif
+
   if (non_blocking) {
     if (safe_nonblocking(fd) < 0) {
       goto Lerror;
@@ -272,6 +310,36 @@ Lerror:
   return res;
 }
 
+int
+Server::setup_fd_after_listen(const NetProcessor::AcceptOptions &opt)
+{
+#ifdef SO_ACCEPTFILTER
+  // SO_ACCEPTFILTER needs to be set **after** listen
+  if (opt.defer_accept > 0) {
+    int file_id = kldfind("accf_data");
+
+    struct kld_file_stat stat;
+    stat.version = sizeof(stat);
+
+    if (kldstat(file_id, &stat) < 0) {
+      Error("[Server::listen] Ignored defer_accept config. Because accf_data module is not loaded errno=%d", errno);
+    } else {
+      struct accept_filter_arg afa;
+
+      bzero(&afa, sizeof(afa));
+      strcpy(afa.af_name, "dataready");
+
+      if (setsockopt(this->fd, SOL_SOCKET, SO_ACCEPTFILTER, &afa, sizeof(afa)) < 0) {
+        Error("[Server::listen] Defer accept is configured but set failed: %d", errno);
+        return -errno;
+      }
+    }
+  }
+#endif
+
+  return 0;
+}
+
 int
 Server::listen(bool non_blocking, const NetProcessor::AcceptOptions &opt)
 {
@@ -303,6 +371,11 @@ Server::listen(bool non_blocking, const NetProcessor::AcceptOptions &opt)
     goto Lerror;
   }
 
+  res = setup_fd_after_listen(opt);
+  if (res < 0) {
+    goto Lerror;
+  }
+
   // Original just did this on port == 0.
   namelen = sizeof(addr);
   if ((res = safe_getsockname(fd, &addr.sa, &namelen))) {
