@@ -180,9 +180,12 @@ struct NetVCOptions {
   static uint32_t const SOCK_OPT_PACKET_MARK = 16;
   /// Value for IP_TOS @c sockopt_flags
   static uint32_t const SOCK_OPT_PACKET_TOS = 32;
+  /// Value for TCP_NOTSENT_LOWAT @c sockopt_flags
+  static uint32_t const SOCK_OPT_TCP_NOTSENT_LOWAT = 64;
 
   uint32_t packet_mark;
   uint32_t packet_tos;
+  uint32_t packet_notsent_lowat;
 
   EventType etype;
 
@@ -202,6 +205,10 @@ struct NetVCOptions {
    */
   ats_scoped_str sni_hostname;
 
+  /** Outbound sni policy which overrides proxy.ssl.client.sni_policy
+   */
+  ats_scoped_str outbound_sni_policy;
+
   /**
    * Client certificate to use in response to OS's certificate request
    */
@@ -221,8 +228,6 @@ struct NetVCOptions {
 
   bool tls_upstream = false;
 
-  /// Reset all values to defaults.
-
   /**
    * Set to DISABLED, PERFMISSIVE, or ENFORCED
    * Controls how the server certificate verification is handled
@@ -234,10 +239,12 @@ struct NetVCOptions {
    * Currently SIGNATURE and NAME
    */
   YamlSNIConfig::Property verifyServerProperties = YamlSNIConfig::Property::NONE;
+
+  /// Reset all values to defaults.
   void reset();
 
   void set_sock_param(int _recv_bufsize, int _send_bufsize, unsigned long _opt_flags, unsigned long _packet_mark = 0,
-                      unsigned long _packet_tos = 0);
+                      unsigned long _packet_tos = 0, unsigned long _packet_notsent_lowat = 0);
 
   NetVCOptions() { reset(); }
   ~NetVCOptions() {}
@@ -385,12 +392,6 @@ public:
   */
   VIO *do_io_read(Continuation *c, int64_t nbytes, MIOBuffer *buf) override = 0;
 
-  virtual Continuation *
-  read_vio_cont()
-  {
-    return nullptr;
-  }
-
   /**
     Initiates write. Thread-safe, may be called when not handling
     an event from the NetVConnection, or the NetVConnection creation
@@ -427,11 +428,6 @@ public:
   */
   VIO *do_io_write(Continuation *c, int64_t nbytes, IOBufferReader *buf, bool owner = false) override = 0;
 
-  virtual Continuation *
-  write_vio_cont()
-  {
-    return nullptr;
-  }
   /**
     Closes the vconnection. A state machine MUST call do_io_close()
     when it has finished with a VConnection. do_io_close() indicates
@@ -468,21 +464,6 @@ public:
   */
   void do_io_shutdown(ShutdownHowTo_t howto) override = 0;
 
-  /**
-    Sends out of band messages over the connection. This function
-    is used to send out of band messages (is this still useful?).
-    cont is called back with VC_EVENT_OOB_COMPLETE - on successful
-    send or VC_EVENT_EOS - if the other side has shutdown the
-    connection. These callbacks could be re-entrant. Only one
-    send_OOB can be in progress at any time for a VC.
-
-    @param cont to be called back with events.
-    @param buf message buffer.
-    @param len length of the message.
-
-  */
-  virtual Action *send_OOB(Continuation *cont, char *buf, int len);
-
   /**
     Return the server name that is appropriate for the network VC type
   */
@@ -492,15 +473,6 @@ public:
     return nullptr;
   }
 
-  /**
-    Cancels a scheduled send_OOB. Part of the message could have
-    been sent already. Not callbacks to the cont are made after
-    this call. The Action returned by send_OOB should not be accessed
-    after cancel_OOB.
-
-  */
-  virtual void cancel_OOB();
-
   ////////////////////////////////////////////////////////////
   // Set the timeouts associated with this connection.      //
   // active_timeout is for the total elapsed time of        //
@@ -625,12 +597,6 @@ public:
   sockaddr const *get_local_addr();
   IpEndpoint const &get_local_endpoint();
 
-  /** Returns local ip.
-      @deprecated get_local_addr() should be used instead for AF_INET6 compatibility.
-  */
-
-  in_addr_t get_local_ip();
-
   /** Returns local port. */
   uint16_t get_local_port();
 
@@ -638,11 +604,6 @@ public:
   sockaddr const *get_remote_addr();
   IpEndpoint const &get_remote_endpoint();
 
-  /** Returns remote ip.
-      @deprecated get_remote_addr() should be used instead for AF_INET6 compatibility.
-  */
-  in_addr_t get_remote_ip();
-
   /** Returns remote port. */
   uint16_t get_remote_port();
 
