@@ -43,6 +43,7 @@ public:
   NetVConnection *allocate_vc(EThread *t) override;
 
   void init() override;
+  void init_socks() override;
 
   Event *accept_thread_event;
 
@@ -50,7 +51,7 @@ public:
   off_t netHandler_offset;
   off_t pollCont_offset;
 
-  // we probably wont need these members
+  // we probably won't need these members
   int n_netthreads;
   EThread **netthreads;
 };
@@ -66,8 +67,6 @@ extern UnixNetProcessor unix_netProcessor;
 //
 // Set up a thread to receive events from the NetProcessor
 // This function should be called for all threads created to
-// accept such events by the EventProcesor.
+// accept such events by the EventProcessor.
 //
 extern void initialize_thread_for_net(EThread *thread);
-
-//#include "UnixNet.h"
