@@ -50,7 +50,7 @@ public:
   check_inactivity(int event, Event *e)
   {
     (void)event;
-    ink_hrtime now = Thread::get_hrtime();
+    ink_hrtime now = ink_get_hrtime();
     NetHandler &nh = *get_NetHandler(this_ethread());
 
     Debug("inactivity_cop_check", "Checking inactivity on Thread-ID #%d", this_ethread()->id);
@@ -267,7 +267,7 @@ initialize_thread_for_net(EThread *thread)
 
 NetHandler::NetHandler() : Continuation(nullptr)
 {
-  SET_HANDLER((NetContHandler)&NetHandler::mainNetEvent);
+  SET_HANDLER(&NetHandler::mainNetEvent);
 }
 
 int
@@ -364,7 +364,7 @@ NetHandler::free_netevent(NetEvent *ne)
   // Release ne from NetHandler
   stopIO(ne);
   // Clear and deallocate ne
-  ne->free(t);
+  ne->free_thread(t);
 }
 
 //
@@ -587,7 +587,7 @@ NetHandler::manage_active_queue(NetEvent *enabling_ne, bool ignore_queue_size =
     return true;
   }
 
-  ink_hrtime now = Thread::get_hrtime();
+  ink_hrtime now = ink_get_hrtime();
 
   // loop over the non-active connections and try to close them
   NetEvent *ne         = active_queue.head;
@@ -634,7 +634,7 @@ void
 NetHandler::manage_keep_alive_queue()
 {
   uint32_t total_connections_in = active_queue_size + keep_alive_queue_size;
-  ink_hrtime now                = Thread::get_hrtime();
+  ink_hrtime now                = ink_get_hrtime();
 
   Debug("v_net_queue", "max_connections_per_thread_in: %d total_connections_in: %d active_queue_size: %d keep_alive_queue_size: %d",
         max_connections_per_thread_in, total_connections_in, active_queue_size, keep_alive_queue_size);
