@@ -21,28 +21,17 @@
   limitations under the License.
  */
 
+#include "FileManager.h"
 #include "tscore/ink_platform.h"
 #include "tscore/ink_file.h"
-#include "tscore/I_Layout.h"
-#include "FileManager.h"
-#include "Main.h"
-#include "Rollback.h"
+#include "ConfigManager.h"
 #include "WebMgmtUtils.h"
-#include "MgmtUtils.h"
-#include "ExpandingArray.h"
-#include "MgmtSocket.h"
 
 #include <vector>
 #include <algorithm>
 
-#define DIR_MODE S_IRWXU
-#define FILE_MODE S_IRWXU
-
 FileManager::FileManager()
 {
-  bindings = ink_hash_table_create(InkHashTableKeyType_String);
-  ink_assert(bindings != nullptr);
-
   ink_mutex_init(&accessLock);
   ink_mutex_init(&cbListLock);
 }
@@ -56,9 +45,6 @@ FileManager::FileManager()
 FileManager::~FileManager()
 {
   callbackListable *cb;
-  Rollback *rb;
-  InkHashTableEntry *entry;
-  InkHashTableIteratorState iterator_state;
 
   // Let other operations finish and do not start any new ones
   ink_mutex_acquire(&accessLock);
@@ -66,16 +52,10 @@ FileManager::~FileManager()
   for (cb = cblist.pop(); cb != nullptr; cb = cblist.pop()) {
     delete cb;
   }
-
-  for (entry = ink_hash_table_iterator_first(bindings, &iterator_state); entry != nullptr;
-       entry = ink_hash_table_iterator_next(bindings, &iterator_state)) {
-    rb = (Rollback *)ink_hash_table_entry_value(bindings, entry);
-
-    delete rb;
+  for (auto &&it : bindings) {
+    delete it.second;
   }
 
-  ink_hash_table_destroy(bindings);
-
   ink_mutex_release(&accessLock);
   ink_mutex_destroy(&accessLock);
   ink_mutex_destroy(&cbListLock);
@@ -102,9 +82,9 @@ FileManager::registerCallback(FileCallbackFunc func)
 }
 
 // void FileManager::addFile(char* fileName, const configFileInfo* file_info,
-//  Rollback* parentRollback)
+//  ConfigManager* parentConfig)
 //
-//  for the baseFile, creates a Rollback object for it
+//  for the baseFile, creates a ConfigManager object for it
 //
 //  if file_info is not null, a WebFileEdit object is also created for
 //    the file
@@ -112,74 +92,76 @@ FileManager::registerCallback(FileCallbackFunc func)
 //  Pointers to the new objects are stored in the bindings hashtable
 //
 void
-FileManager::addFile(const char *fileName, bool root_access_needed, Rollback *parentRollback, unsigned flags)
+FileManager::addFile(const char *fileName, const char *configName, bool root_access_needed, bool isRequired,
+                     ConfigManager *parentConfig)
 {
   ink_mutex_acquire(&accessLock);
-  addFileHelper(fileName, root_access_needed, parentRollback, flags);
+  addFileHelper(fileName, configName, root_access_needed, isRequired, parentConfig);
   ink_mutex_release(&accessLock);
 }
 
 // caller must hold the lock
 void
-FileManager::addFileHelper(const char *fileName, bool root_access_needed, Rollback *parentRollback, unsigned flags)
+FileManager::addFileHelper(const char *fileName, const char *configName, bool root_access_needed, bool isRequired,
+                           ConfigManager *parentConfig)
 {
   ink_assert(fileName != nullptr);
 
-  Rollback *rb    = new Rollback(fileName, root_access_needed, parentRollback, flags);
-  rb->configFiles = this;
+  ConfigManager *rb = new ConfigManager(fileName, configName, root_access_needed, isRequired, parentConfig);
+  rb->configFiles   = this;
 
-  ink_hash_table_insert(bindings, fileName, rb);
+  bindings.emplace(rb->getFileName(), rb);
 }
 
-// bool FileManager::getRollbackObj(char* fileName, Rollback** rbPtr)
+// bool FileManager::getConfigManagerObj(char* fileName, ConfigManager** rbPtr)
 //
-//  Sets rbPtr to the rollback object associated
+//  Sets rbPtr to the ConfigManager object associated
 //    with the passed in fileName.
 //
-//  If there is no binding, falseis returned
+//  If there is no binding, false is returned
 //
 bool
-FileManager::getRollbackObj(const char *fileName, Rollback **rbPtr)
+FileManager::getConfigObj(const char *fileName, ConfigManager **rbPtr)
 {
-  InkHashTableValue lookup = nullptr;
-  int found;
-
   ink_mutex_acquire(&accessLock);
-  found = ink_hash_table_lookup(bindings, fileName, &lookup);
+  auto it    = bindings.find(fileName);
+  bool found = it != bindings.end();
   ink_mutex_release(&accessLock);
 
-  *rbPtr = (Rollback *)lookup;
-  return (found == 0) ? false : true;
+  *rbPtr = found ? it->second : nullptr;
+  return found;
 }
 
 // bool FileManager::fileChanged(const char* fileName)
 //
-//  Called by the Rollback class whenever a a config has changed
+//  Called by the ConfigManager class whenever a config has changed
 //     Initiates callbacks
 //
 //
 void
-FileManager::fileChanged(const char *fileName, bool incVersion)
+FileManager::fileChanged(const char *fileName, const char *configName)
 {
   callbackListable *cb;
-  char *filenameCopy;
+  char *filenameCopy, *confignameCopy;
   Debug("lm", "filename changed %s", fileName);
   ink_mutex_acquire(&cbListLock);
 
   for (cb = cblist.head; cb != nullptr; cb = cb->link.next) {
     // Dup the string for each callback to be
-    //  defensive incase it modified when it is not supposed to be
-    filenameCopy = ats_strdup(fileName);
-    (*cb->func)(filenameCopy, incVersion);
+    //  defensive in case it's modified when it's not supposed to be
+    confignameCopy = ats_strdup(configName);
+    filenameCopy   = ats_strdup(fileName);
+    (*cb->func)(filenameCopy, confignameCopy);
     ats_free(filenameCopy);
+    ats_free(confignameCopy);
   }
   ink_mutex_release(&cbListLock);
 }
 
 // void FileManger::rereadConfig()
 //
-//   Interates through the list of managed files and
-//     calls Rollback::checkForUserUpdate on them
+//   Iterates through the list of managed files and
+//     calls ConfigManager::checkForUserUpdate on them
 //
 //   although it is tempting, DO NOT CALL FROM SIGNAL HANDLERS
 //      This function is not Async-Signal Safe.  It
@@ -187,39 +169,37 @@ FileManager::fileChanged(const char *fileName, bool incVersion)
 void
 FileManager::rereadConfig()
 {
-  Rollback *rb;
-  InkHashTableEntry *entry;
-  InkHashTableIteratorState iterator_state;
+  ConfigManager *rb;
 
-  std::vector<Rollback *> changedFiles;
-  std::vector<Rollback *> parentFileNeedChange;
+  std::vector<ConfigManager *> changedFiles;
+  std::vector<ConfigManager *> parentFileNeedChange;
   size_t n;
   ink_mutex_acquire(&accessLock);
-  for (entry = ink_hash_table_iterator_first(bindings, &iterator_state); entry != nullptr;
-       entry = ink_hash_table_iterator_next(bindings, &iterator_state)) {
-    rb = (Rollback *)ink_hash_table_entry_value(bindings, entry);
-    if (rb->checkForUserUpdate(rb->isVersioned() ? ROLLBACK_CHECK_AND_UPDATE : ROLLBACK_CHECK_ONLY)) {
+  for (auto &&it : bindings) {
+    rb = it.second;
+    // ToDo: rb->isVersions() was always true before, because numberBackups was always >= 1. So ROLLBACK_CHECK_ONLY could not
+    // happen at all...
+    if (rb->checkForUserUpdate(ROLLBACK_CHECK_AND_UPDATE)) {
       changedFiles.push_back(rb);
-      if (rb->isChildRollback()) {
-        if (std::find(parentFileNeedChange.begin(), parentFileNeedChange.end(), rb->getParentRollback()) ==
+      if (rb->isChildManaged()) {
+        if (std::find(parentFileNeedChange.begin(), parentFileNeedChange.end(), rb->getParentConfig()) ==
             parentFileNeedChange.end()) {
-          parentFileNeedChange.push_back(rb->getParentRollback());
+          parentFileNeedChange.push_back(rb->getParentConfig());
         }
       }
     }
   }
 
-  std::vector<Rollback *> childFileNeedDelete;
+  std::vector<ConfigManager *> childFileNeedDelete;
   n = changedFiles.size();
   for (size_t i = 0; i < n; i++) {
-    if (changedFiles[i]->isChildRollback()) {
+    if (changedFiles[i]->isChildManaged()) {
       continue;
     }
     // for each parent file, if it is changed, then delete all its children
-    for (entry = ink_hash_table_iterator_first(bindings, &iterator_state); entry != nullptr;
-         entry = ink_hash_table_iterator_next(bindings, &iterator_state)) {
-      rb = (Rollback *)ink_hash_table_entry_value(bindings, entry);
-      if (rb->getParentRollback() == changedFiles[i]) {
+    for (auto &&it : bindings) {
+      rb = it.second;
+      if (rb->getParentConfig() == changedFiles[i]) {
         if (std::find(childFileNeedDelete.begin(), childFileNeedDelete.end(), rb) == childFileNeedDelete.end()) {
           childFileNeedDelete.push_back(rb);
         }
@@ -228,7 +208,7 @@ FileManager::rereadConfig()
   }
   n = childFileNeedDelete.size();
   for (size_t i = 0; i < n; i++) {
-    ink_hash_table_delete(bindings, childFileNeedDelete[i]->getFileName());
+    bindings.erase(childFileNeedDelete[i]->getFileName());
     delete childFileNeedDelete[i];
   }
   ink_mutex_release(&accessLock);
@@ -236,31 +216,29 @@ FileManager::rereadConfig()
   n = parentFileNeedChange.size();
   for (size_t i = 0; i < n; i++) {
     if (std::find(changedFiles.begin(), changedFiles.end(), parentFileNeedChange[i]) == changedFiles.end()) {
-      fileChanged(parentFileNeedChange[i]->getFileName(), true);
+      fileChanged(parentFileNeedChange[i]->getFileName(), parentFileNeedChange[i]->getConfigName());
     }
   }
   // INKqa11910
   // need to first check that enable_customizations is enabled
   bool found;
-  int enabled = (int)REC_readInteger("proxy.config.body_factory.enable_customizations", &found);
+  int enabled = static_cast<int>(REC_readInteger("proxy.config.body_factory.enable_customizations", &found));
+
   if (found && enabled) {
-    fileChanged("proxy.config.body_factory.template_sets_dir", true);
+    fileChanged("proxy.config.body_factory.template_sets_dir", "proxy.config.body_factory.template_sets_dir");
   }
-  fileChanged("proxy.config.ssl.server.ticket_key.filename", true);
+  fileChanged("proxy.config.ssl.server.ticket_key.filename", "proxy.config.ssl.server.ticket_key.filename");
 }
 
 bool
 FileManager::isConfigStale()
 {
-  Rollback *rb;
-  InkHashTableEntry *entry;
-  InkHashTableIteratorState iterator_state;
+  ConfigManager *rb;
   bool stale = false;
 
   ink_mutex_acquire(&accessLock);
-  for (entry = ink_hash_table_iterator_first(bindings, &iterator_state); entry != nullptr;
-       entry = ink_hash_table_iterator_next(bindings, &iterator_state)) {
-    rb = (Rollback *)ink_hash_table_entry_value(bindings, entry);
+  for (auto &&it : bindings) {
+    rb = it.second;
     if (rb->checkForUserUpdate(ROLLBACK_CHECK_ONLY)) {
       stale = true;
       break;
@@ -273,17 +251,15 @@ FileManager::isConfigStale()
 
 // void configFileChild(const char *parent, const char *child)
 //
-// Add child to the bindings with parentRollback
+// Add child to the bindings with parentConfig
 void
-FileManager::configFileChild(const char *parent, const char *child, unsigned flags)
+FileManager::configFileChild(const char *parent, const char *child)
 {
-  InkHashTableValue lookup;
-  Rollback *parentRollback = nullptr;
+  ConfigManager *parentConfig = nullptr;
   ink_mutex_acquire(&accessLock);
-  int htfound = ink_hash_table_lookup(bindings, parent, &lookup);
-  if (htfound) {
-    parentRollback = (Rollback *)lookup;
-    addFileHelper(child, parentRollback->rootAccessNeeded(), parentRollback, flags);
+  if (auto it = bindings.find(parent); it != bindings.end()) {
+    parentConfig = it->second;
+    addFileHelper(child, "", parentConfig->rootAccessNeeded(), parentConfig->getIsRequired(), parentConfig);
   }
   ink_mutex_release(&accessLock);
 }
