@@ -26,6 +26,7 @@
 #include <pcre.h>
 #endif
 
+#include <string>
 #include <mutex>
 
 // Data Structures and Classes
@@ -41,9 +42,15 @@ struct Config {
   RegexType m_regex_type{None};
   pcre *m_regex{nullptr};
   pcre_extra *m_regex_extra{nullptr};
-  int m_paceerrsecs{0}; // -1 disable logging, 0 no pacing, max 60s
+  int m_paceerrsecs{0};   // -1 disable logging, 0 no pacing, max 60s
+  int m_prefetchcount{0}; // 0 disables prefetching
   enum RefType { First, Relative };
-  RefType m_reftype{First}; // reference slice is relative to request
+  RefType m_reftype{First};           // reference slice is relative to request
+  const char *m_method_type{nullptr}; // type of header request
+  bool m_head_strip_range{false};     // strip range header for head requests
+
+  std::string m_skip_header;
+  std::string m_crr_ims_header;
 
   // Convert optarg to bytes
   static int64_t bytesFrom(char const *const valstr);
@@ -64,6 +71,13 @@ struct Config {
     return None != m_regex_type;
   }
 
+  // Check if response only expects header
+  bool
+  onlyHeader() const
+  {
+    return (m_method_type == TS_HTTP_METHOD_HEAD || m_method_type == TS_HTTP_METHOD_PURGE);
+  }
+
   // If no null reg, true, otherwise check against regex
   bool matchesRegex(char const *const url, int const urllen) const;
 
