@@ -21,6 +21,7 @@
 //
 #include <arpa/inet.h>
 #include <cstring>
+#include <algorithm>
 
 #include "ts/ts.h"
 
@@ -164,6 +165,17 @@ OperatorSetDestination::initialize(Parser &p)
   require_resources(RSRC_SERVER_REQUEST_HEADERS);
 }
 
+// OperatorRMDestination
+void
+OperatorRMDestination::initialize(Parser &p)
+{
+  Operator::initialize(p);
+
+  _url_qual = parse_url_qualifier(p.get_arg());
+  require_resources(RSRC_CLIENT_REQUEST_HEADERS);
+  require_resources(RSRC_SERVER_REQUEST_HEADERS);
+}
+
 void
 OperatorSetDestination::exec(const Resources &res) const
 {
@@ -273,6 +285,54 @@ OperatorSetDestination::exec(const Resources &res) const
   }
 }
 
+void
+OperatorRMDestination::exec(const Resources &res) const
+{
+  if (res._rri || (res.bufp && res.hdr_loc)) {
+    // Default empty string to delete components
+    static std::string value = "";
+
+    // Determine which TSMBuffer and TSMLoc to use
+    TSMBuffer bufp;
+    TSMLoc url_m_loc;
+    if (res._rri) {
+      bufp      = res._rri->requestBufp;
+      url_m_loc = res._rri->requestUrl;
+    } else {
+      bufp = res.bufp;
+      if (TSHttpHdrUrlGet(res.bufp, res.hdr_loc, &url_m_loc) != TS_SUCCESS) {
+        TSDebug(PLUGIN_NAME, "TSHttpHdrUrlGet was unable to return the url m_loc");
+        return;
+      }
+    }
+
+    // Never set an empty destination value (I don't think that ever makes sense?)
+    switch (_url_qual) {
+    case URL_QUAL_PATH:
+      const_cast<Resources &>(res).changed_url = true;
+      TSUrlPathSet(bufp, url_m_loc, value.c_str(), value.size());
+      TSDebug(PLUGIN_NAME, "OperatorRMDestination::exec() deleting PATH");
+      break;
+    case URL_QUAL_QUERY:
+      const_cast<Resources &>(res).changed_url = true;
+      TSUrlHttpQuerySet(bufp, url_m_loc, value.c_str(), value.size());
+      TSDebug(PLUGIN_NAME, "OperatorRMDestination::exec() deleting QUERY");
+      break;
+    case URL_QUAL_PORT:
+      const_cast<Resources &>(res).changed_url = true;
+      TSUrlPortSet(bufp, url_m_loc, 0);
+      TSDebug(PLUGIN_NAME, "OperatorRMDestination::exec() deleting PORT");
+      break;
+    default:
+      TSDebug(PLUGIN_NAME, "RM Destination %i has no handler", _url_qual);
+      break;
+    }
+  } else {
+    TSDebug(PLUGIN_NAME, "OperatorRMDestination::exec() unable to continue due to missing bufp=%p or hdr_loc=%p, rri=%p!", res.bufp,
+            res.hdr_loc, res._rri);
+  }
+}
+
 // OperatorSetRedirect
 void
 OperatorSetRedirect::initialize(Parser &p)
@@ -489,6 +549,7 @@ OperatorSetTimeoutOut::exec(const Resources &res) const
 }
 
 // OperatorSkipRemap
+// Deprecated: Remove for v10.0.0
 void
 OperatorSkipRemap::initialize(Parser &p)
 {
@@ -503,7 +564,7 @@ void
 OperatorSkipRemap::exec(const Resources &res) const
 {
   TSDebug(PLUGIN_NAME, "OperatorSkipRemap::exec() skipping remap: %s", _skip_remap ? "True" : "False");
-  TSSkipRemappingSet(res.txnp, _skip_remap ? 1 : 0);
+  TSHttpTxnCntlSet(res.txnp, TS_HTTP_CNTL_SKIP_REMAPPING, _skip_remap);
 }
 
 // OperatorRMHeader
@@ -618,6 +679,32 @@ OperatorSetHeader::exec(const Resources &res) const
   }
 }
 
+// OperatorSetBody
+void
+OperatorSetBody::initialize(Parser &p)
+{
+  Operator::initialize(p);
+  // we want the arg since body only takes one value
+  _value.set_value(p.get_arg());
+}
+
+void
+OperatorSetBody::initialize_hooks()
+{
+  add_allowed_hook(TS_HTTP_READ_RESPONSE_HDR_HOOK);
+  add_allowed_hook(TS_HTTP_SEND_RESPONSE_HDR_HOOK);
+}
+
+void
+OperatorSetBody::exec(const Resources &res) const
+{
+  std::string value;
+
+  _value.append_value(value, res);
+  char *msg = TSstrdup(_value.get_value().c_str());
+  TSHttpTxnErrorBodySet(res.txnp, msg, _value.size(), nullptr);
+}
+
 // OperatorCounter
 void
 OperatorCounter::initialize(Parser &p)
@@ -923,6 +1010,7 @@ OperatorSetConnMark::exec(const Resources &res) const
 }
 
 // OperatorSetDebug
+// Deprecated: Remove for v10.0.0
 void
 OperatorSetDebug::initialize(Parser &p)
 {
@@ -940,5 +1028,72 @@ OperatorSetDebug::initialize_hooks()
 void
 OperatorSetDebug::exec(const Resources &res) const
 {
-  TSHttpTxnDebugSet(res.txnp, 1);
+  TSHttpTxnCntlSet(res.txnp, TS_HTTP_CNTL_TXN_DEBUG, true);
+}
+
+// OperatorSetHttpCntl
+TSHttpCntlType
+parse_cntl_qualifier(const std::string &q) // Helper function for parsing modifiers
+{
+  TSHttpCntlType qual = TS_HTTP_CNTL_LOGGING_MODE;
+
+  if (q == "LOGGING") {
+    qual = TS_HTTP_CNTL_LOGGING_MODE;
+  } else if (q == "INTERCEPT_RETRY") {
+    qual = TS_HTTP_CNTL_INTERCEPT_RETRY_MODE;
+  } else if (q == "RESP_CACHEABLE") {
+    qual = TS_HTTP_CNTL_RESPONSE_CACHEABLE;
+  } else if (q == "REQ_CACHEABLE") {
+    qual = TS_HTTP_CNTL_REQUEST_CACHEABLE;
+  } else if (q == "SERVER_NO_STORE") {
+    qual = TS_HTTP_CNTL_SERVER_NO_STORE;
+  } else if (q == "TXN_DEBUG") {
+    qual = TS_HTTP_CNTL_TXN_DEBUG;
+  } else if (q == "SKIP_REMAP") {
+    qual = TS_HTTP_CNTL_SKIP_REMAPPING;
+  } else {
+    TSError("[%s] Invalid HTTP-CNTL() qualifier: %s", PLUGIN_NAME, q.c_str());
+  }
+
+  return qual;
+}
+
+void
+OperatorSetHttpCntl::initialize(Parser &p)
+{
+  Operator::initialize(p);
+  _cntl_qual = parse_cntl_qualifier(p.get_arg());
+
+  std::string flag = p.copy_value();
+
+  std::transform(flag.begin(), flag.end(), flag.begin(), ::tolower);
+
+  if (flag == "1" || flag == "true" || flag == "on" || flag == "enable") {
+    _flag = true;
+  }
+}
+
+void
+OperatorSetHttpCntl::initialize_hooks()
+{
+  add_allowed_hook(TS_HTTP_READ_REQUEST_HDR_HOOK);
+  add_allowed_hook(TS_HTTP_READ_RESPONSE_HDR_HOOK);
+  add_allowed_hook(TS_HTTP_SEND_RESPONSE_HDR_HOOK);
+  add_allowed_hook(TS_REMAP_PSEUDO_HOOK);
+}
+
+// This is only for the debug statement, and must be in sync with TSHttpCntlType in apidefs.h.in
+static const char *const HttpCntls[] = {
+  "LOGGING", "INTERCEPT_RETRY", "RESP_CACHEABLE", "REQ_CACHEABLE", "SERVER_NO_STORE", "TXN_DEBUG", "SKIP_REMAP",
+};
+void
+OperatorSetHttpCntl::exec(const Resources &res) const
+{
+  if (_flag) {
+    TSHttpTxnCntlSet(res.txnp, _cntl_qual, true);
+    TSDebug(PLUGIN_NAME, "   Turning ON %s for transaction", HttpCntls[static_cast<size_t>(_cntl_qual)]);
+  } else {
+    TSHttpTxnCntlSet(res.txnp, _cntl_qual, false);
+    TSDebug(PLUGIN_NAME, "   Turning OFF %s for transaction", HttpCntls[static_cast<size_t>(_cntl_qual)]);
+  }
 }
