@@ -53,7 +53,7 @@ public:
   mark(T ms)
   {
     if (this->_milestones[static_cast<size_t>(ms)] == 0) {
-      this->_milestones[static_cast<size_t>(ms)] = Thread::get_hrtime();
+      this->_milestones[static_cast<size_t>(ms)] = ink_get_hrtime();
     }
   }
 
@@ -64,10 +64,10 @@ public:
    * @return The difference time in milliseconds
    */
   int64_t
-  difference_msec(T ms_start, T ms_end) const
+  difference_msec(T ms_start, T ms_end, int64_t missing = -1) const // Return "missing" when Milestone is not set
   {
     if (this->_milestones[static_cast<size_t>(ms_end)] == 0) {
-      return -1;
+      return missing;
     }
     return ink_hrtime_to_msec(this->_milestones[static_cast<size_t>(ms_end)] - this->_milestones[static_cast<size_t>(ms_start)]);
   }
