@@ -143,7 +143,7 @@ ParentConsistentHash::selectParent(bool first_call, ParentResult *result, Reques
   uint32_t last_lookup;
   pRecord *prtmp = nullptr, *pRec = nullptr;
   HostStatus &pStatus    = HostStatus::instance();
-  HostStatus_t host_stat = HostStatus_t::HOST_STATUS_INIT;
+  TSHostStatus host_stat = TSHostStatus::TS_HOST_STATUS_INIT;
 
   Debug("parent_select", "ParentConsistentHash::%s(): Using a consistent hash parent selection strategy.", __func__);
   ink_assert(numParents(result) > 0 || result->rec->go_direct == true);
@@ -174,7 +174,7 @@ ParentConsistentHash::selectParent(bool first_call, ParentResult *result, Reques
       last_lookup = PRIMARY;
       break;
     case 3:
-      if (result->first_choice_status == HOST_STATUS_DOWN && chash[SECONDARY] != nullptr) {
+      if (result->first_choice_status == TS_HOST_STATUS_DOWN && chash[SECONDARY] != nullptr) {
         last_lookup = SECONDARY;
       } else {
         last_lookup = PRIMARY;
@@ -215,39 +215,33 @@ ParentConsistentHash::selectParent(bool first_call, ParentResult *result, Reques
 
   // didn't find a parent or the parent is marked unavailable or the parent is marked down
   HostStatRec *hst = (pRec) ? pStatus.getHostStatus(pRec->hostname) : nullptr;
-  host_stat        = (hst) ? hst->status : HostStatus_t::HOST_STATUS_UP;
+  host_stat        = (hst) ? hst->status : TSHostStatus::TS_HOST_STATUS_UP;
   if (firstCall) {
     result->first_choice_status = host_stat;
   }
 
   // if the config ignore_self_detect is set to true and the host is down due to SELF_DETECT reason
   // ignore the down status and mark it as available
-  if ((pRec && result->rec->ignore_self_detect) && (hst && hst->status == HOST_STATUS_DOWN)) {
+  if ((pRec && result->rec->ignore_self_detect) && (hst && hst->status == TS_HOST_STATUS_DOWN)) {
     if (hst->reasons == Reason::SELF_DETECT) {
-      host_stat = HOST_STATUS_UP;
+      host_stat = TS_HOST_STATUS_UP;
     }
   }
-  if (!pRec || (pRec && !pRec->available.load()) || host_stat == HOST_STATUS_DOWN) {
+  if (!pRec || (pRec && !pRec->available.load()) || host_stat == TS_HOST_STATUS_DOWN) {
     do {
       // check if the host is retryable.  It's retryable if the retry window has elapsed
       // and the global host status is HOST_STATUS_UP
-      if (pRec && !pRec->available.load() && host_stat == HOST_STATUS_UP) {
+      if (pRec && !pRec->available.load() && host_stat == TS_HOST_STATUS_UP) {
         Debug("parent_select", "Parent.failedAt = %u, retry = %u, xact_start = %u", static_cast<unsigned>(pRec->failedAt.load()),
               static_cast<unsigned>(retry_time), static_cast<unsigned>(request_info->xact_start));
         if ((pRec->failedAt.load() + retry_time) < request_info->xact_start) {
-          if (pRec->retriers.fetch_add(1, std::memory_order_relaxed) < max_retriers) {
-            parentRetry = true;
-            // make sure that the proper state is recorded in the result structure
-            result->last_parent = pRec->idx;
-            result->last_lookup = last_lookup;
-            result->retry       = parentRetry;
-            result->result      = PARENT_SPECIFIED;
-            Debug("parent_select", "Down parent %s is now retryable, retriers = %d, max_retriers = %d", pRec->hostname,
-                  pRec->retriers.load(), max_retriers);
-            break;
-          } else {
-            pRec->retriers--;
-          }
+          parentRetry = true;
+          // make sure that the proper state is recorded in the result structure
+          result->last_parent = pRec->idx;
+          result->last_lookup = last_lookup;
+          result->retry       = parentRetry;
+          result->result      = PARENT_SPECIFIED;
+          break;
         }
       }
       Debug("parent_select", "wrap_around[PRIMARY]: %d, wrap_around[SECONDARY]: %d", wrap_around[PRIMARY], wrap_around[SECONDARY]);
@@ -262,7 +256,7 @@ ParentConsistentHash::selectParent(bool first_call, ParentResult *result, Reques
           }
           break;
         case 3:
-          if (result->first_choice_status == HOST_STATUS_DOWN) {
+          if (result->first_choice_status == TS_HOST_STATUS_DOWN) {
             if (chash[SECONDARY] != nullptr && !wrap_around[SECONDARY]) {
               last_lookup = SECONDARY;
             } else if (!wrap_around[PRIMARY]) {
@@ -304,15 +298,15 @@ ParentConsistentHash::selectParent(bool first_call, ParentResult *result, Reques
         break;
       }
       hst       = (pRec) ? pStatus.getHostStatus(pRec->hostname) : nullptr;
-      host_stat = (hst) ? hst->status : HostStatus_t::HOST_STATUS_UP;
+      host_stat = (hst) ? hst->status : TSHostStatus::TS_HOST_STATUS_UP;
       // if the config ignore_self_detect is set to true and the host is down due to SELF_DETECT reason
       // ignore the down status and mark it as available
-      if ((pRec && result->rec->ignore_self_detect) && (hst && hst->status == HOST_STATUS_DOWN)) {
+      if ((pRec && result->rec->ignore_self_detect) && (hst && hst->status == TS_HOST_STATUS_DOWN)) {
         if (hst->reasons == Reason::SELF_DETECT) {
-          host_stat = HOST_STATUS_UP;
+          host_stat = TS_HOST_STATUS_UP;
         }
       }
-    } while (!pRec || !pRec->available.load() || host_stat == HOST_STATUS_DOWN);
+    } while (!pRec || !pRec->available.load() || host_stat == TS_HOST_STATUS_DOWN);
   }
 
   Debug("parent_select", "Additional parent lookups: %d", lookups);
@@ -323,12 +317,12 @@ ParentConsistentHash::selectParent(bool first_call, ParentResult *result, Reques
 
   // if the config ignore_self_detect is set to true and the host is down due to SELF_DETECT reason
   // ignore the down status and mark it as available
-  if ((pRec && result->rec->ignore_self_detect) && (hst && hst->status == HOST_STATUS_DOWN)) {
+  if ((pRec && result->rec->ignore_self_detect) && (hst && hst->status == TS_HOST_STATUS_DOWN)) {
     if (hst->reasons == Reason::SELF_DETECT) {
-      host_stat = HOST_STATUS_UP;
+      host_stat = TS_HOST_STATUS_UP;
     }
   }
-  if (pRec && host_stat == HOST_STATUS_UP && (pRec->available.load() || result->retry)) {
+  if (pRec && host_stat == TS_HOST_STATUS_UP && (pRec->available.load() || result->retry)) {
     result->result      = PARENT_SPECIFIED;
     result->hostname    = pRec->hostname;
     result->port        = pRec->port;
@@ -374,7 +368,7 @@ ParentConsistentHash::markParentUp(ParentResult *result)
 {
   pRecord *pRec;
 
-  //  Make sure that we are being called back with with a
+  //  Make sure that we are being called back with a
   //   result structure with a parent that is being retried
   ink_release_assert(result->retry == true);
   ink_assert(result->result == PARENT_SPECIFIED);
@@ -395,7 +389,6 @@ ParentConsistentHash::markParentUp(ParentResult *result)
 
   pRec->failedAt = static_cast<time_t>(0);
   int old_count  = pRec->failCount.exchange(0, std::memory_order_relaxed);
-  pRec->retriers = 0;
 
   if (old_count > 0) {
     Note("http parent proxy %s:%d restored", pRec->hostname, pRec->port);
