@@ -94,7 +94,7 @@ SCENARIO("Testing NextHopConsistentHash class, using policy 'consistent_hash'",
         result->reset();
         strategy->findNextHop(txnp);
 
-        CHECK(result->result == ParentResultType::PARENT_SPECIFIED);
+        REQUIRE(result->result == ParentResultType::PARENT_SPECIFIED);
         CHECK(strcmp(result->hostname, "p1.foo.com") == 0);
 
         // mark down p1.foo.com.  markNextHop looks at the 'result'
@@ -107,7 +107,7 @@ SCENARIO("Testing NextHopConsistentHash class, using policy 'consistent_hash'",
         build_request(10002, &sm, nullptr, "rabbit.net", nullptr);
         strategy->findNextHop(txnp);
 
-        CHECK(result->result == ParentResultType::PARENT_SPECIFIED);
+        REQUIRE(result->result == ParentResultType::PARENT_SPECIFIED);
         CHECK(strcmp(result->hostname, "p2.foo.com") == 0);
 
         // mark down p2.foo.com
@@ -118,7 +118,7 @@ SCENARIO("Testing NextHopConsistentHash class, using policy 'consistent_hash'",
         build_request(10003, &sm, nullptr, "rabbit.net", nullptr);
         strategy->findNextHop(txnp);
 
-        CHECK(result->result == ParentResultType::PARENT_SPECIFIED);
+        REQUIRE(result->result == ParentResultType::PARENT_SPECIFIED);
         CHECK(strcmp(result->hostname, "s2.bar.com") == 0);
 
         // mark down s2.bar.com
@@ -129,7 +129,7 @@ SCENARIO("Testing NextHopConsistentHash class, using policy 'consistent_hash'",
         build_request(10004, &sm, nullptr, "rabbit.net", nullptr);
         strategy->findNextHop(txnp);
 
-        CHECK(result->result == ParentResultType::PARENT_SPECIFIED);
+        REQUIRE(result->result == ParentResultType::PARENT_SPECIFIED);
         CHECK(strcmp(result->hostname, "s1.bar.com") == 0);
 
         // mark down s1.bar.com.
@@ -140,7 +140,7 @@ SCENARIO("Testing NextHopConsistentHash class, using policy 'consistent_hash'",
         build_request(10005, &sm, nullptr, "rabbit.net", nullptr);
         strategy->findNextHop(txnp);
 
-        CHECK(result->result == ParentResultType::PARENT_SPECIFIED);
+        REQUIRE(result->result == ParentResultType::PARENT_SPECIFIED);
         CHECK(strcmp(result->hostname, "q1.bar.com") == 0);
 
         // mark down q1.bar.com
@@ -150,7 +150,7 @@ SCENARIO("Testing NextHopConsistentHash class, using policy 'consistent_hash'",
         build_request(10006, &sm, nullptr, "rabbit.net", nullptr);
         strategy->findNextHop(txnp);
 
-        CHECK(result->result == ParentResultType::PARENT_SPECIFIED);
+        REQUIRE(result->result == ParentResultType::PARENT_SPECIFIED);
         CHECK(strcmp(result->hostname, "q2.bar.com") == 0);
 
         // mark down q2.bar.com
@@ -170,7 +170,7 @@ SCENARIO("Testing NextHopConsistentHash class, using policy 'consistent_hash'",
         // simulating a failure triggers a search for another parent, not firstcall.
         build_request(10008, &sm, nullptr, "rabbit.net", nullptr);
         strategy->findNextHop(txnp, nullptr, now);
-        CHECK(result->result == ParentResultType::PARENT_SPECIFIED);
+        REQUIRE(result->result == ParentResultType::PARENT_SPECIFIED);
         CHECK(strcmp(result->hostname, "q2.bar.com") == 0);
 
         // free up request resources.
@@ -225,7 +225,7 @@ SCENARIO("Testing NextHopConsistentHash class (all firstcalls), using policy 'co
         build_request(20001, &sm, nullptr, "rabbit.net", nullptr);
         result->reset();
         strategy->findNextHop(txnp);
-        CHECK(result->result == ParentResultType::PARENT_SPECIFIED);
+        REQUIRE(result->result == ParentResultType::PARENT_SPECIFIED);
         CHECK(strcmp(result->hostname, "p1.foo.com") == 0);
 
         // mark down p1.foo.com
@@ -234,7 +234,7 @@ SCENARIO("Testing NextHopConsistentHash class (all firstcalls), using policy 'co
         build_request(20002, &sm, nullptr, "rabbit.net", nullptr);
         result->reset();
         strategy->findNextHop(txnp);
-        CHECK(result->result == ParentResultType::PARENT_SPECIFIED);
+        REQUIRE(result->result == ParentResultType::PARENT_SPECIFIED);
         CHECK(strcmp(result->hostname, "p2.foo.com") == 0);
 
         // mark down p2.foo.com
@@ -244,7 +244,7 @@ SCENARIO("Testing NextHopConsistentHash class (all firstcalls), using policy 'co
         result->reset();
         build_request(20003, &sm, nullptr, "rabbit.net", nullptr);
         strategy->findNextHop(txnp);
-        CHECK(result->result == ParentResultType::PARENT_SPECIFIED);
+        REQUIRE(result->result == ParentResultType::PARENT_SPECIFIED);
         CHECK(strcmp(result->hostname, "s2.bar.com") == 0);
 
         // mark down s2.bar.com
@@ -254,7 +254,7 @@ SCENARIO("Testing NextHopConsistentHash class (all firstcalls), using policy 'co
         result->reset();
         build_request(20004, &sm, nullptr, "rabbit.net", nullptr);
         strategy->findNextHop(txnp);
-        CHECK(result->result == ParentResultType::PARENT_SPECIFIED);
+        REQUIRE(result->result == ParentResultType::PARENT_SPECIFIED);
         CHECK(strcmp(result->hostname, "s1.bar.com") == 0);
 
         // mark down s1.bar.com
@@ -264,7 +264,7 @@ SCENARIO("Testing NextHopConsistentHash class (all firstcalls), using policy 'co
         result->reset();
         build_request(20005, &sm, nullptr, "rabbit.net/asset1", nullptr);
         strategy->findNextHop(txnp);
-        CHECK(result->result == ParentResultType::PARENT_SPECIFIED);
+        REQUIRE(result->result == ParentResultType::PARENT_SPECIFIED);
         CHECK(strcmp(result->hostname, "q1.bar.com") == 0);
 
         // sixth request - wait and p1 should now become available
@@ -272,7 +272,7 @@ SCENARIO("Testing NextHopConsistentHash class (all firstcalls), using policy 'co
         result->reset();
         build_request(20006, &sm, nullptr, "rabbit.net", nullptr);
         strategy->findNextHop(txnp, nullptr, now);
-        CHECK(result->result == ParentResultType::PARENT_SPECIFIED);
+        REQUIRE(result->result == ParentResultType::PARENT_SPECIFIED);
         CHECK(strcmp(result->hostname, "p1.foo.com") == 0);
       }
       // free up request resources.
@@ -297,7 +297,7 @@ SCENARIO("Testing NextHop ignore_self_detect false", "[NextHopConsistentHash]")
     strategy = nhf.strategyInstance("ignore-self-detect-false");
 
     HostStatus &hs = HostStatus::instance();
-    hs.setHostStatus("localhost", HostStatus_t::HOST_STATUS_DOWN, 0, Reason::SELF_DETECT);
+    hs.setHostStatus("localhost", TSHostStatus::TS_HOST_STATUS_DOWN, 0, Reason::SELF_DETECT);
 
     WHEN("the config is loaded.")
     {
@@ -347,7 +347,7 @@ SCENARIO("Testing NextHop ignore_self_detect true", "[NextHopConsistentHash]")
     strategy = nhf.strategyInstance("ignore-self-detect-true");
 
     HostStatus &hs = HostStatus::instance();
-    hs.setHostStatus("localhost", HostStatus_t::HOST_STATUS_DOWN, 0, Reason::SELF_DETECT);
+    hs.setHostStatus("localhost", TSHostStatus::TS_HOST_STATUS_DOWN, 0, Reason::SELF_DETECT);
 
     WHEN("the config is loaded.")
     {
@@ -372,7 +372,7 @@ SCENARIO("Testing NextHop ignore_self_detect true", "[NextHopConsistentHash]")
         build_request(10001, &sm, nullptr, "rabbit.net", nullptr);
         result->reset();
         strategy->findNextHop(txnp);
-        CHECK(result->result == ParentResultType::PARENT_SPECIFIED);
+        REQUIRE(result->result == ParentResultType::PARENT_SPECIFIED);
         CHECK(strcmp(result->hostname, "localhost") == 0);
         CHECK(result->port == 8000);
         br_destroy(sm);
@@ -422,7 +422,7 @@ SCENARIO("Testing NextHopConsistentHash same host different port markdown", "[Ne
         result->reset();
         strategy->findNextHop(txnp);
 
-        CHECK(result->result == ParentResultType::PARENT_SPECIFIED);
+        REQUIRE(result->result == ParentResultType::PARENT_SPECIFIED);
         CHECK(strcmp(result->hostname, "localhost") == 0);
         CHECK(result->port == 8000);
 
@@ -431,7 +431,7 @@ SCENARIO("Testing NextHopConsistentHash same host different port markdown", "[Ne
         build_request(10002, &sm, nullptr, "rabbit.net", nullptr);
         strategy->findNextHop(txnp);
 
-        CHECK(result->result == ParentResultType::PARENT_SPECIFIED);
+        REQUIRE(result->result == ParentResultType::PARENT_SPECIFIED);
         CHECK(strcmp(result->hostname, "localhost") == 0);
         CHECK(result->port == 8002);
 
@@ -440,7 +440,7 @@ SCENARIO("Testing NextHopConsistentHash same host different port markdown", "[Ne
         build_request(10003, &sm, nullptr, "rabbit.net", nullptr);
         strategy->findNextHop(txnp);
 
-        CHECK(result->result == ParentResultType::PARENT_SPECIFIED);
+        REQUIRE(result->result == ParentResultType::PARENT_SPECIFIED);
         CHECK(strcmp(result->hostname, "localhost") == 0);
         CHECK(result->port == 8004);
         br_destroy(sm);
@@ -492,7 +492,7 @@ SCENARIO("Testing NextHopConsistentHash hash_string override", "[NextHopConsiste
         // We happen to know that 'foo.test' will be first if the hostname is the hash
         // and foo.test will be first for the hash 'first' and the bar.test hash 'second'.
         // So, if the hash_string override isn't getting applied, this will fail.
-        CHECK(result->result == ParentResultType::PARENT_SPECIFIED);
+        REQUIRE(result->result == ParentResultType::PARENT_SPECIFIED);
         CHECK(strcmp(result->hostname, "bar.test") == 0);
         CHECK(result->port == 80);
 
@@ -501,6 +501,7 @@ SCENARIO("Testing NextHopConsistentHash hash_string override", "[NextHopConsiste
         build_request(10002, &sm, nullptr, "rabbit.net", nullptr);
         strategy->findNextHop(txnp);
 
+        REQUIRE(result->result == ParentResultType::PARENT_SPECIFIED);
         CHECK(strcmp(result->hostname, "foo.test") == 0);
         CHECK(result->port == 80);
         br_destroy(sm);
@@ -550,7 +551,7 @@ SCENARIO("Testing NextHopConsistentHash class (alternating rings), using policy
         build_request(30001, &sm, nullptr, "bunny.net/asset1", nullptr);
         result->reset();
         strategy->findNextHop(txnp);
-        CHECK(result->result == ParentResultType::PARENT_SPECIFIED);
+        REQUIRE(result->result == ParentResultType::PARENT_SPECIFIED);
         CHECK(strcmp(result->hostname, "c2.foo.com") == 0);
 
         // simulated failure, mark c2 down and retry request
@@ -559,7 +560,7 @@ SCENARIO("Testing NextHopConsistentHash class (alternating rings), using policy
         // second request
         build_request(30002, &sm, nullptr, "bunny.net.net/asset1", nullptr);
         strategy->findNextHop(txnp);
-        CHECK(result->result == ParentResultType::PARENT_SPECIFIED);
+        REQUIRE(result->result == ParentResultType::PARENT_SPECIFIED);
         CHECK(strcmp(result->hostname, "c3.bar.com") == 0);
 
         // mark down c3.bar.com
@@ -569,7 +570,7 @@ SCENARIO("Testing NextHopConsistentHash class (alternating rings), using policy
         build_request(30003, &sm, nullptr, "bunny.net/asset2", nullptr);
         result->reset();
         strategy->findNextHop(txnp);
-        CHECK(result->result == ParentResultType::PARENT_SPECIFIED);
+        REQUIRE(result->result == ParentResultType::PARENT_SPECIFIED);
         CHECK(strcmp(result->hostname, "c6.bar.com") == 0);
 
         // just mark it down and retry request
@@ -577,7 +578,7 @@ SCENARIO("Testing NextHopConsistentHash class (alternating rings), using policy
         // fourth request
         build_request(30004, &sm, nullptr, "bunny.net/asset2", nullptr);
         strategy->findNextHop(txnp);
-        CHECK(result->result == ParentResultType::PARENT_SPECIFIED);
+        REQUIRE(result->result == ParentResultType::PARENT_SPECIFIED);
         CHECK(strcmp(result->hostname, "c1.foo.com") == 0);
 
         // mark it down
@@ -586,7 +587,7 @@ SCENARIO("Testing NextHopConsistentHash class (alternating rings), using policy
         build_request(30005, &sm, nullptr, "bunny.net/asset3", nullptr);
         result->reset();
         strategy->findNextHop(txnp);
-        CHECK(result->result == ParentResultType::PARENT_SPECIFIED);
+        REQUIRE(result->result == ParentResultType::PARENT_SPECIFIED);
         CHECK(strcmp(result->hostname, "c4.bar.com") == 0);
 
         // mark it down and retry
@@ -595,7 +596,7 @@ SCENARIO("Testing NextHopConsistentHash class (alternating rings), using policy
         result->reset();
         build_request(30006, &sm, nullptr, "bunny.net/asset3", nullptr);
         strategy->findNextHop(txnp);
-        CHECK(result->result == ParentResultType::PARENT_SPECIFIED);
+        REQUIRE(result->result == ParentResultType::PARENT_SPECIFIED);
         CHECK(strcmp(result->hostname, "c5.bar.com") == 0);
 
         // mark it down
@@ -604,7 +605,7 @@ SCENARIO("Testing NextHopConsistentHash class (alternating rings), using policy
         result->reset();
         build_request(30007, &sm, nullptr, "bunny.net/asset4", nullptr);
         strategy->findNextHop(txnp);
-        CHECK(result->result == ParentResultType::PARENT_FAIL);
+        REQUIRE(result->result == ParentResultType::PARENT_FAIL);
         CHECK(result->hostname == nullptr);
 
         // eighth request - retry after waiting for the retry window to expire.
@@ -612,7 +613,7 @@ SCENARIO("Testing NextHopConsistentHash class (alternating rings), using policy
         result->reset();
         build_request(30008, &sm, nullptr, "bunny.net/asset4", nullptr);
         strategy->findNextHop(txnp, nullptr, now);
-        CHECK(result->result == ParentResultType::PARENT_SPECIFIED);
+        REQUIRE(result->result == ParentResultType::PARENT_SPECIFIED);
         CHECK(strcmp(result->hostname, "c2.foo.com") == 0);
       }
       // free up request resources.
@@ -620,3 +621,39 @@ SCENARIO("Testing NextHopConsistentHash class (alternating rings), using policy
     }
   }
 }
+
+// jjr
+//
+SCENARIO("Testing NextHopConsistentHash using a peering ring_mode.")
+{
+  // We need this to build a HdrHeap object in build_request();
+  // No thread setup, forbid use of thread local allocators.
+  cmd_disable_pfreelist = true;
+  // Get all of the HTTP WKS items populated.
+  http_init();
+
+  GIVEN("Loading the peering.yaml config for 'consistent_hash' tests.")
+  {
+    std::shared_ptr<NextHopSelectionStrategy> strategy;
+    NextHopStrategyFactory nhf(TS_SRC_DIR "unit-tests/peering.yaml");
+    strategy = nhf.strategyInstance("peering-group-1");
+
+    WHEN("the config is loaded.")
+    {
+      THEN("then testing consistent hash.")
+      {
+        REQUIRE(nhf.strategies_loaded == true);
+        REQUIRE(strategy != nullptr);
+        REQUIRE(strategy->groups == 2);
+        REQUIRE(strategy->ring_mode == NH_PEERING_RING);
+        REQUIRE(strategy->policy_type == NH_CONSISTENT_HASH);
+        for (std::size_t i = 0; i < strategy->host_groups.size(); ++i) {
+          for (auto const &elem : strategy->host_groups[i]) {
+            bool should_be_self = elem.get()->hostname == "p3.bar.com" && i == 0;
+            REQUIRE(elem.get()->self == should_be_self);
+          }
+        }
+      }
+    }
+  }
+}
