@@ -67,8 +67,8 @@ DiagsConfig::reconfigure_diags()
   all_found = true;
 
   // initial value set to 0 or 1 based on command line tags
-  c.enabled[DiagsTagType_Debug]  = (diags->base_debug_tags != nullptr);
-  c.enabled[DiagsTagType_Action] = (diags->base_action_tags != nullptr);
+  c.enabled[DiagsTagType_Debug]  = (_diags->base_debug_tags != nullptr);
+  c.enabled[DiagsTagType_Action] = (_diags->base_action_tags != nullptr);
 
   // enabled if records.config set
 
@@ -84,9 +84,9 @@ DiagsConfig::reconfigure_diags()
   }
   all_found = all_found && found;
 
-  e                    = static_cast<int>(REC_readInteger("proxy.config.diags.show_location", &found));
-  diags->show_location = ((e == 1 && found) ? SHOW_LOCATION_DEBUG : ((e == 2 && found) ? SHOW_LOCATION_ALL : SHOW_LOCATION_NONE));
-  all_found            = all_found && found;
+  e                     = static_cast<int>(REC_readInteger("proxy.config.diags.show_location", &found));
+  _diags->show_location = ((e == 1 && found) ? SHOW_LOCATION_DEBUG : ((e == 2 && found) ? SHOW_LOCATION_ALL : SHOW_LOCATION_NONE));
+  all_found             = all_found && found;
 
   // read output routing values
   for (i = 0;; i++) {
@@ -128,23 +128,23 @@ DiagsConfig::reconfigure_diags()
     // clear out old tag tables //
     //////////////////////////////
 
-    diags->deactivate_all(DiagsTagType_Debug);
-    diags->deactivate_all(DiagsTagType_Action);
+    _diags->deactivate_all(DiagsTagType_Debug);
+    _diags->deactivate_all(DiagsTagType_Action);
 
     //////////////////////////////////////////////////////////////////////
     // add new tag tables from records.config or command line overrides //
     //////////////////////////////////////////////////////////////////////
 
-    diags->activate_taglist((diags->base_debug_tags ? diags->base_debug_tags : dt), DiagsTagType_Debug);
-    diags->activate_taglist((diags->base_action_tags ? diags->base_action_tags : at), DiagsTagType_Action);
+    _diags->activate_taglist((_diags->base_debug_tags ? _diags->base_debug_tags : dt), DiagsTagType_Debug);
+    _diags->activate_taglist((_diags->base_action_tags ? _diags->base_action_tags : at), DiagsTagType_Action);
 
 ////////////////////////////////////
 // change the diags config values //
 ////////////////////////////////////
 #if !defined(__GNUC__)
-    diags->config = c;
+    _diags->config = c;
 #else
-    memcpy(((void *)&diags->config), ((void *)&c), sizeof(DiagsConfigState));
+    memcpy(((void *)&_diags->config), ((void *)&c), sizeof(DiagsConfigState));
 #endif
     Note("updated diags config");
   }
@@ -172,7 +172,7 @@ diags_config_callback(const char * /* name ATS_UNUSED */, RecDataT /* data_type
   DiagsConfig *diagsConfig;
 
   diagsConfig = static_cast<DiagsConfig *>(opaque_token);
-  ink_assert(diags->magic == DIAGS_MAGIC);
+  ink_assert(::diags->magic == DIAGS_MAGIC);
   diagsConfig->reconfigure_diags();
   return (0);
 }
@@ -217,39 +217,38 @@ DiagsConfig::config_diags_norecords()
   //////////////////////////////
   // clear out old tag tables //
   //////////////////////////////
-  diags->deactivate_all(DiagsTagType_Debug);
-  diags->deactivate_all(DiagsTagType_Action);
+  _diags->deactivate_all(DiagsTagType_Debug);
+  _diags->deactivate_all(DiagsTagType_Action);
 
   //////////////////////////////////////////////////////////////////////
   // add new tag tables from command line overrides only              //
   //////////////////////////////////////////////////////////////////////
 
-  if (diags->base_debug_tags) {
-    diags->activate_taglist(diags->base_debug_tags, DiagsTagType_Debug);
+  if (_diags->base_debug_tags) {
+    _diags->activate_taglist(_diags->base_debug_tags, DiagsTagType_Debug);
     c.enabled[DiagsTagType_Debug] = true;
   } else {
     c.enabled[DiagsTagType_Debug] = false;
   }
 
-  if (diags->base_action_tags) {
-    diags->activate_taglist(diags->base_action_tags, DiagsTagType_Action);
+  if (_diags->base_action_tags) {
+    _diags->activate_taglist(_diags->base_action_tags, DiagsTagType_Action);
     c.enabled[DiagsTagType_Action] = true;
   } else {
     c.enabled[DiagsTagType_Action] = false;
   }
 
 #if !defined(__GNUC__)
-  diags->config = c;
+  _diags->config = c;
 #else
-  memcpy(((void *)&diags->config), ((void *)&c), sizeof(DiagsConfigState));
+  memcpy(((void *)&_diags->config), ((void *)&c), sizeof(DiagsConfigState));
 #endif
 }
 
 DiagsConfig::DiagsConfig(std::string_view prefix_string, const char *filename, const char *tags, const char *actions,
                          bool use_records)
-  : callbacks_established(false), diags_log(nullptr), diags(nullptr)
+  : callbacks_established(false), diags_log(nullptr), _diags(nullptr)
 {
-  char diags_logpath[PATH_NAME_MAX];
   ats_scoped_str logpath;
 
   ////////////////////////////////////////////////////////////////////
@@ -259,7 +258,8 @@ DiagsConfig::DiagsConfig(std::string_view prefix_string, const char *filename, c
   ////////////////////////////////////////////////////////////////////
 
   if (!use_records) {
-    diags = new Diags(prefix_string, tags, actions, nullptr);
+    _diags  = new Diags(prefix_string, tags, actions, nullptr);
+    ::diags = _diags;
     config_diags_norecords();
     return;
   }
@@ -274,7 +274,16 @@ DiagsConfig::DiagsConfig(std::string_view prefix_string, const char *filename, c
     ::exit(1);
   }
 
-  ink_filepath_make(diags_logpath, sizeof(diags_logpath), logpath, filename);
+  std::string diags_logpath{filename};
+  // "stdout" and "stderr" are treated specially by BaseLogFile and are used to
+  // write to the stdout and stderr streams, respectively. If the caller
+  // specified these, we don't prepend any path and simply pass those strings
+  // as such to BaseLogFile.
+  if (diags_logpath != "stdout" && diags_logpath != "stderr") {
+    char buf[PATH_NAME_MAX];
+    ink_filepath_make(buf, sizeof(buf), logpath, filename);
+    diags_logpath = std::string(buf);
+  }
 
   // Grab rolling intervals from configuration
   // TODO error check these values
@@ -295,13 +304,14 @@ DiagsConfig::DiagsConfig(std::string_view prefix_string, const char *filename, c
   ats_free(output_perm);
 
   // Set up diags, FILE streams are opened in Diags constructor
-  diags_log = new BaseLogFile(diags_logpath);
-  diags     = new Diags(prefix_string, tags, actions, diags_log, diags_perm_parsed, output_perm_parsed);
-  diags->config_roll_diagslog(static_cast<RollingEnabledValues>(diags_log_roll_enable), diags_log_roll_int, diags_log_roll_size);
-  diags->config_roll_outputlog(static_cast<RollingEnabledValues>(output_log_roll_enable), output_log_roll_int,
-                               output_log_roll_size);
+  diags_log = new BaseLogFile(diags_logpath.c_str());
+  _diags    = new Diags(prefix_string, tags, actions, diags_log, diags_perm_parsed, output_perm_parsed);
+  ::diags   = _diags;
+  _diags->config_roll_diagslog(static_cast<RollingEnabledValues>(diags_log_roll_enable), diags_log_roll_int, diags_log_roll_size);
+  _diags->config_roll_outputlog(static_cast<RollingEnabledValues>(output_log_roll_enable), output_log_roll_int,
+                                output_log_roll_size);
 
-  Status("opened %s", diags_logpath);
+  Status("opened %s", diags_logpath.c_str());
 
   register_diags_callbacks();
 
@@ -354,5 +364,5 @@ DiagsConfig::register_diags_callbacks()
 
 DiagsConfig::~DiagsConfig()
 {
-  delete diags;
+  delete _diags;
 }
