@@ -915,6 +915,24 @@ bwformat(BufferWriter &w, BWFSpec const &spec, bwf::Errno const &e)
   return w;
 }
 
+BufferWriter &
+bwformat(BufferWriter &w, BWFSpec const &spec, std::error_code const &ec)
+{
+  // This provides convenient safe access to the errno short name array.
+  static const BWFormat number_fmt{"[{}]"_sv}; // numeric value format.
+  if (spec.has_numeric_type()) {               // if numeric type, print just the numeric
+    // part.
+    w.print(number_fmt, ec.value());
+  } else {
+    w.write(ec.message());
+    if (spec._type != 's' && spec._type != 'S') {
+      w.write(' ');
+      w.print(number_fmt, ec.value());
+    }
+  }
+  return w;
+}
+
 bwf::Date::Date(std::string_view fmt) : _epoch(std::chrono::system_clock::to_time_t(std::chrono::system_clock::now())), _fmt(fmt) {}
 
 BufferWriter &
